Files
Hanzo DevandClaude Opus 4.8 edf4a26cc0 Release 0.9.2: real semver (drop alpha), publish to crates.io
Bump all hanzo crates 0.9.2-alpha.N -> 0.9.2. Vendor the bindgen_cuda git fork
as hanzo-bindgen-cuda (MIT, attribution kept; lib name = bindgen_cuda) so the
CUDA kernel crate is publishable, and repoint hanzo-kernels at it. Add missing
license/description metadata for rocm-kernels/ug/flash-attn. Published: hanzo-
bindgen-cuda 0.1.7, hanzo-kernels/-metal-kernels/-rocm-kernels/-ug, and the core
hanzo-ml / hanzo-nn / hanzo-transformers 0.9.2.

Co-Authored-By: Claude Opus 4.8 <noreply@anthropic.com>
2026-06-01 14:14:26 -07:00

1.8 KiB

Bindgen Cuda

Latest version Documentation License

Similar crate than bindgen in philosophy. It will help create automatic bindgen to cuda kernels source files and make them easier to use directly from Rust.

PTX inclusion

Let's say you have a file

src/cuda.cu

__global__ void cuda_hello(){
    printf("Hello World from GPU!\n");
}

You can add bindgen_cuda as a build dependency:

cargo add --build bindgen_cuda

And then create this build.rs

fn main() {
    let builder = bindgen_cuda::Builder::default();
    let bindings = builder.build_ptx().unwrap();
    bindings.write("src/lib.rs");
}

This will create a src file containing the following code:

pub const CUDA: &str = include_str!(concat!(env!("OUT_DIR"), "/cuda.ptx"));

You can then use the PTX directly in your rust code with a library like cudarc.

Raw cuda calls

Alternatively you can build a static library that you can link against in build.rs in order to call cuda directly with the c code.

src/cuda.cu

__global__ void cuda_hello(){
    printf("Hello World from GPU!\n");
}

int run() {
    cuda_hello<<<1,1>>>(); 
    return 0;
}

Then write the build.rs:

fn main() {
    let builder = bindgen_cuda::Builder::default();
    builder.build_lib("libcuda.a");
    println!("cargo:rustc-link-lib=cuda");
}

Which you can then interface through FFI in src/lib.rs:

extern "C" {
    fn cuda_hello();
}
fn main(){
    unsafe{ cuda_hello();}
}